@@ -77,6 +77,11 @@ static const char* KEY_GMT_TIME      = "gmt_time";
 static const char* KEY_CONFIG_TOOL   = "config_tool";
 static const char* KEY_CUSTOM_FORMAT = "custom_format";
 
+static const char *clock_config_tools [] = {
+	"redhat-config-date",
+	"time-admin",
+};
+
 typedef enum {
 	CLOCK_FORMAT_12,
 	CLOCK_FORMAT_24,
@@ -154,6 +159,9 @@ static void display_help_dialog       (BonoboUIComponent *uic,
 static void display_about_dialog      (BonoboUIComponent *uic,
 				       ClockData         *cd,
 				       const gchar       *verbname);
+static void position_calendar_popup   (ClockData         *cd,
+                                       GtkWidget         *window,
+                                       GtkWidget         *button);
 
 static void
 unfix_size (ClockData *cd)
@@ -590,7 +598,8 @@ enum {
 
 static char *
 format_time (ClockFormat format,
-             time_t      t)
+             time_t      t,
+             gboolean    use_utc)
 {
         struct tm *tm;
         char      *time_format;
@@ -599,7 +608,10 @@ format_time (ClockFormat format,
         if (!t)
                 return NULL;
 
-        tm = localtime (&t);
+        if (use_utc)
+                tm = gmtime (&t);
+        else
+                tm = localtime (&t);
         if (!tm)
                 return NULL;
 
@@ -655,6 +667,8 @@ handle_tasks_changed (ClockData *cd)
         g_slist_free (events);
 
         update_frame_visibility (cd->task_list, GTK_TREE_MODEL (cd->tasks_filter));
+        if (cd->calendar_popup && GTK_WIDGET_REALIZED (cd->toggle))
+                position_calendar_popup (cd, cd->calendar_popup, cd->toggle);
 }
 
 static void
@@ -956,7 +970,8 @@ handle_appointments_changed (ClockData *cd)
 
                 if (!appointment->is_all_day)
                         start_text = format_time (cd->format,
-                                                  appointment->start_time);
+                                                  appointment->start_time,
+                                                  cd->gmt_time);
                 else
                         start_text = g_strdup (_("All Day"));
 
@@ -977,6 +992,8 @@ handle_appointments_changed (ClockData *cd)
         g_slist_free (events);
 
         update_frame_visibility (cd->appointment_list, GTK_TREE_MODEL (cd->appointments_model));
+        if (cd->calendar_popup && GTK_WIDGET_REALIZED (cd->toggle))
+                position_calendar_popup (cd, cd->calendar_popup, cd->toggle);
 }
 
 static GtkWidget *
@@ -1150,17 +1167,26 @@ add_appointments_and_tasks (ClockData *cd,
         cd->task_list = create_task_list (cd, &tree_view);
         g_object_add_weak_pointer (G_OBJECT (cd->task_list),
                                    (gpointer *) &cd->task_list);
-        gtk_box_pack_start (GTK_BOX (vbox), cd->task_list, TRUE, TRUE, 0);
         setup_list_size_constraint (cd->task_list, cd->calendar, tree_view);
         update_frame_visibility (cd->task_list, GTK_TREE_MODEL (cd->tasks_model));
         
         cd->appointment_list = create_appointment_list (cd, &tree_view);
         g_object_add_weak_pointer (G_OBJECT (cd->appointment_list),
                                    (gpointer *) &cd->appointment_list);
-        gtk_box_pack_start (GTK_BOX (vbox), cd->appointment_list, TRUE, TRUE, 0);
         setup_list_size_constraint (cd->appointment_list, cd->calendar, tree_view);
         update_frame_visibility (cd->appointment_list, GTK_TREE_MODEL (cd->appointments_model));
 
+        switch (cd->orient) {
+        case PANEL_APPLET_ORIENT_UP:
+                gtk_box_pack_start (GTK_BOX (vbox), cd->appointment_list, TRUE, TRUE, 0);
+                gtk_box_pack_start (GTK_BOX (vbox), cd->task_list, TRUE, TRUE, 0);
+                break;
+        default:
+                gtk_box_pack_start (GTK_BOX (vbox), cd->task_list, TRUE, TRUE, 0);
+                gtk_box_pack_start (GTK_BOX (vbox), cd->appointment_list, TRUE, TRUE, 0);
+                break;
+        }
+
         if (!cd->client) {
                 cd->client = calendar_client_new ();
 
@@ -1230,24 +1256,34 @@ create_calendar (ClockData *cd,
 	options |= GTK_CALENDAR_SHOW_WEEK_NUMBERS;
 	gtk_calendar_set_display_options (GTK_CALENDAR (cd->calendar), options);
 
-        tm = localtime (&cd->current_time);
+	if (cd->gmt_time)
+		tm = gmtime (&cd->current_time);
+	else
+		tm = localtime (&cd->current_time);
         gtk_calendar_select_month (GTK_CALENDAR (cd->calendar),
                                    tm->tm_mon,
                                    tm->tm_year + 1900);
         gtk_calendar_select_day (GTK_CALENDAR (cd->calendar), tm->tm_mday);
 
-	gtk_box_pack_start (GTK_BOX (vbox), cd->calendar, TRUE, FALSE, 0);
-	gtk_widget_show (cd->calendar);
-
-        add_appointments_and_tasks (cd, vbox);
+	switch (cd->orient) {
+        case PANEL_APPLET_ORIENT_UP:
+                add_appointments_and_tasks (cd, vbox);
+                gtk_box_pack_start (GTK_BOX (vbox), cd->calendar, TRUE, FALSE, 0);
+                break;
+        default:
+                gtk_box_pack_start (GTK_BOX (vbox), cd->calendar, TRUE, FALSE, 0);
+                add_appointments_and_tasks (cd, vbox);
+                break;
+        }
+        gtk_widget_show (cd->calendar);
 
 	return GTK_WIDGET (window);
 }
 
 static void
-present_calendar_popup (ClockData *cd,
-			GtkWidget *window,
-			GtkWidget *button)
+position_calendar_popup (ClockData *cd,
+                         GtkWidget *window,
+                         GtkWidget *button)
 {
 	GtkRequisition  req;
 	GdkScreen      *screen;
@@ -1320,7 +1356,15 @@ present_calendar_popup (ClockData *cd,
 	}
 		
 	gtk_window_move (GTK_WINDOW (window), x, y);
-	gtk_window_present (GTK_WINDOW (window));
+}
+
+static void
+present_calendar_popup (ClockData *cd,
+			GtkWidget *window,
+			GtkWidget *button)
+{
+        position_calendar_popup (cd, window, button);
+        gtk_window_present (GTK_WINDOW (window));
 }
 
 static void
@@ -1616,19 +1660,17 @@ config_date (BonoboUIComponent *uic,
 {
 	GtkWidget *dialog;
 	GdkScreen *screen;
+	int i;
 
 	screen = gtk_widget_get_screen (cd->applet);
 
-	/* FIXME add other time config tools. */
-	if (cd->config_tool && cd->config_tool[0]
-	    && try_config_tool (screen, cd->config_tool))
-		return;
-
-	else if (try_config_tool (screen, "redhat-config-date"))
-		return;
-		
-	else if (try_config_tool (screen, "time-admin"))
+	if (cd->config_tool && cd->config_tool[0] &&
+            try_config_tool (screen, cd->config_tool))
 		return;
+	
+	for (i = 0; i < G_N_ELEMENTS (clock_config_tools); i++)
+		if (try_config_tool (screen, clock_config_tools [i]))
+			return;
 		
 	dialog = gtk_message_dialog_new (NULL,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1869,10 +1911,12 @@ clock_migrate_to_26 (ClockData *clock)
 static gboolean
 fill_clock_applet (PanelApplet *applet)
 {
-	ClockData *cd;
-	GError    *error;
-	char      *format_str;
-	int        format_int;
+	ClockData         *cd;
+	BonoboUIComponent *popup_component;
+	GError            *error;
+	char              *format_str;
+	int                format_int;
+	char              *config_tool;
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/clock_applet/prefs", NULL);
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
@@ -1958,11 +2002,9 @@ fill_clock_applet (PanelApplet *applet)
 					   clock_menu_verbs,
 					   cd);
 
+	popup_component = panel_applet_get_popup_component (PANEL_APPLET (cd->applet));
+
 	if (panel_applet_get_locked_down (PANEL_APPLET (cd->applet))) {
-		BonoboUIComponent *popup_component;
-
-		popup_component = panel_applet_get_popup_component (PANEL_APPLET (cd->applet));
-
 		bonobo_ui_component_set_prop (popup_component,
 					      "/commands/ClockPreferences",
 					      "hidden", "1",
@@ -1972,6 +2014,26 @@ fill_clock_applet (PanelApplet *applet)
 					      "hidden", "1",
 					      NULL);
 	}
+
+        config_tool = NULL;
+	if (cd->config_tool && cd->config_tool [0])
+		config_tool = g_find_program_in_path (cd->config_tool);
+
+        if (!config_tool) {
+                int i;
+
+                for (i = 0; i < G_N_ELEMENTS (clock_config_tools); i++)
+                        if ((config_tool = g_find_program_in_path (clock_config_tools [i])))
+                                break;
+        }
+
+	if (!config_tool)
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/ClockConfig",
+					      "hidden", "1",
+					      NULL);
+        
+        g_free (config_tool);
 	
 	return TRUE;
 }
