@@ -22,15 +22,16 @@ struct _ButtonWidget {
 	GdkPixbuf        *scaled;
 	GdkPixbuf        *scaled_hc;
 
-	/* Invariant: assert (!filename || !stock_id) */
+	/* if filename doesn't lead to a findable icon,
+	   try stock_id */
 	char             *filename;
 	char             *stock_id;
 
 	PanelOrientation  orientation;
 
-	guint             pressed_timeout;
 	int               size;
 
+	guint             activatable   : 1;
 	guint             ignore_leave  : 1;
 	guint             arrow         : 1;
 	guint             dnd_highlight : 1;
@@ -47,6 +48,9 @@ GtkWidget *      button_widget_new               (const char       *pixmap,
 GtkWidget *      button_widget_new_from_stock    (const char       *stock_id,
 						  gboolean          arrow,
 						  PanelOrientation  orientation);
+void             button_widget_set_activatable   (ButtonWidget     *button,
+						  gboolean          activatable);
+gboolean         button_widget_get_activatable   (ButtonWidget     *button);
 void             button_widget_set_icon_name     (ButtonWidget     *button,
 						  const char       *icon_name);
 const char *     button_widget_get_icon_name     (ButtonWidget     *button);
