@@ -695,7 +695,7 @@ on_help_button_clicked (GtkWidget *widget, gpointer data)
 	GError *error = NULL;
 
         gnome_help_display_desktop (NULL, "user-guide", 
-				    "wgoseditmainmenu.xml", "goseditmainmenu-53", 
+				    "user-guide.xml", "goseditmainmenu-53", 
 				    &error);
 	
 	if (error) {
