@@ -583,7 +583,7 @@ window_response (GtkWidget *w, int response, gpointer data)
 	if (response == GTK_RESPONSE_HELP) {
 		panel_show_help (
 			gtk_window_get_screen (GTK_WINDOW (w)),
-			"wgospanel.xml", "gospanel-52");
+			"user-guide.xml", "gospanel-52");
 	} else if (response == REVERT_BUTTON) { /* revert */
 		if (launcher->ditem != NULL)
 			gnome_desktop_item_unref (launcher->ditem);
@@ -910,7 +910,7 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 	} else if (response == GTK_RESPONSE_HELP) {
 		panel_show_help (
 			gtk_window_get_screen (GTK_WINDOW (dialog)),
-			"wgospanel.xml", "gospanel-52");
+			"user-guide.xml", "gospanel-52");
 		/* just return as we don't want to close */
 		return;
 	}
