@@ -3056,7 +3056,7 @@ static void
 show_panel_help (GtkWidget *w, gpointer data)
 {
 	panel_show_help (
-		gtk_widget_get_screen (w), "wgospanel.xml", NULL);
+		gtk_widget_get_screen (w), "user-guide.xml", NULL);
 }
 
 GtkWidget *
@@ -3538,7 +3538,8 @@ panel_menu_key_press_handler (GtkWidget   *widget,
 {
 	gboolean retval = FALSE;
 
-	if (event->keyval == GDK_F10 && event->state == GDK_SHIFT_MASK) {
+	if (event->keyval == GDK_F10 &&
+	    (event->state & gtk_accelerator_get_default_mod_mask ()) == GDK_SHIFT_MASK) {
 		GtkMenuShell *menu_shell = GTK_MENU_SHELL (widget);
 
 		retval = TRUE;
